@@ -63,11 +63,22 @@ ddca_ddcutil_version(void);
 /**
  * Returns the ddcutil version as a string in the form "major.minor.micro".
  *
- * @return version string.
+ * @return version string (caller must not free)
  */
 const char *
 ddca_ddcutil_version_string(void);
 
+
+/** Returns the full ddcutil version as a string, possibly with a suffix,
+ *
+ * @return string in form "1.3.0" or "1.3.0-dev" (caller must not free)
+ *
+ * @since 1.2.0
+ */
+const char *
+ddca_ddcutil_extended_version_string(void);
+
+
 // Bit ids for ddca_get_build_options() - how to make connection in doxygen?
 #ifdef ALT
  * Defined Bits
@@ -409,7 +420,7 @@ void
 ddca_add_traced_file(
       const char * filename);
 
-/* Specify one or more trace groups.
+/** Replaces the groups being traced
  *
  *  \param[in] trace_flags  bitfield indicating groups to trace
  */
@@ -417,6 +428,18 @@ void
 ddca_set_trace_groups(
       DDCA_Trace_Group trace_flags);
 
+
+/** Adds to the groups being traced
+ *
+ *  \param[in] trace_flags  bitfield indicating groups to trace
+ *
+ *  @since 1.2.0
+ */
+void
+ddca_add_trace_groups(
+      DDCA_Trace_Group trace_flags);
+
+
 /** Given a trace group name, returns its identifier.
  *  Case is ignored.
  *
@@ -519,11 +542,52 @@ ddca_enable_usb_display_detection(bool onoff);
 /** Reports whether USB devices are checked as part of display detection
  *
  *  @retval true  USB devices are checked
- *  @retval valse UBB devices are not checked
+ *  @retval false USB devices are not checked
  */
 bool
 ddca_ddca_is_usb_display_detection_enabled();
 
+/** Gets display references list for all detected displays.
+ *
+ *  @param[in]  include_invalid_displays if true, displays that do not support DDC are included
+ *  @param[out] drefs_loc where to return pointer to null-terminated array of #DDCA_Display_Ref
+ *  @retval     0  always succeeds
+ *
+ *  @since 1.2.0
+ */
+DDCA_Status
+ddca_get_display_refs(
+      bool                include_invalid_displays,
+      DDCA_Display_Ref**  drefs_loc);
+
+/** Gets publicly visible information about a display reference
+ *
+ *  The returned struct can simply be free()'d by the client.
+ *
+ *  @param  ddca_dref display reference
+ *  @param  dinfo_loc where to return pointer to newly allocated #DDCA_Display_Info
+ *
+ *  @since 1.2.0
+ */
+DDCA_Status
+ddca_get_display_info(
+      DDCA_Display_Ref  ddca_dref,
+      DDCA_Display_Info ** dinfo_loc);
+
+/** Frees a #DDCA_Display_Info struct.
+ *
+ *  This is a convenience function. #DDCA_Display_Info is copied to
+ *  the client and contains no pointers.  It can simply be free()'d
+ *  by the client.
+ *
+ *  @param info_rec pointer to instance to free
+ *
+ *  @since 1.2.0
+ */
+
+void
+ddca_free_display_info(DDCA_Display_Info * info_rec);
+
 /** Gets a list of the detected displays.
  *
  *  @param[in]  include_invalid_displays if true, displays that do not support DDC are included
@@ -537,9 +601,9 @@ ddca_get_display_info_list2(
 
 /** Frees a list of detected displays.
  *
- *  This function understands which fields in the list
- *  point to permanently allocated data structures and should
- *  not be freed.
+ *  This is a convenience function. #DDCA_Display_Info_List
+ *  contains no pointers and is copied to the client, so the
+ *  list can simply be free'd by the client.
  *
  *  \param[in] dlist pointer to #DDCA_Display_Info_List
  */
@@ -585,6 +649,20 @@ ddca_report_displays(
       bool include_invalid_displays,
       int  depth);
 
+/** Reinitializes detected displays
+ *
+ *  - closes all open displays, releasing any display locks
+ *  - n. all existing display handles become invalid (TODO: validate dh similarly to dref)
+ *  - releases display refs (all existing display refs become invalid)
+ *  - releases i2c bus info
+ *  - rescans i2c buses
+ *  - redetects displays
+ *
+ *  @since 1.2.0
+ */
+DDCA_Status
+ddca_redetect_displays();
+
 
 //
 // Display Identifier
